@@ -3,4 +3,4 @@ from django.apps import AppConfig
 
 class DjangoSwapUser(AppConfig):
     name = "swap_user"
-    verbose_name = "Django Swap EmailUser"
+    verbose_name = "Django Swap User"
